/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugin.ezproxy

import metridoc.schema.BaseSchema

v32 = "VARCHAR(32)"
v2000 = "VARCHAR(2000)"
bun = "BIGINT UNSIGNED"

schema {

    include BaseSchema.class

    changeSet(id: "ezproxy_base_01", author: "metridoc", dbms: "mysql,h2") {
        constructLoadingTable()
        constructMasterTable()
    }
}

def constructLoadingTable() {
    def tableName = "ezproxy_loading"
    def columns = [patron_ip: v32, city: v32, state: v32, country: v32, patron_id: v32, proxy_time: "DATETIME",
            http_method: "VARCHAR(12)", url: v2000, response_code: "INT", response_size: "INT", ref_url: v2000,
            agent:"TEXT", cookies: "TEXT", source_file: v32, line_num: "INT", ezproxy_id:v32]

    schemaUtils.createBasicTable(tableName, columns)
    schemaUtils.addNotNullConstraints(tableName, [source_file: v32, line_num: "INT"])
}

def constructMasterTable() {
    def tableName = "ez_log_master"
    def columns = [data_file_id:bun, line_number:"INT", ip_address_id:bun, resource_id:bun, proxy_time:"DATETIME"]
    schemaUtils.createBasicTable(tableName, columns)
    schemaUtils.addNotNullConstraints(tableName, [data_file_id:bun, line_number:"INT", proxy_time:"DATETIME"])
}